/**
 * @fileoverview no custom variables exported in page config
 * @author acity
 */
"use strict";

//------------------------------------------------------------------------------
// Rule Definition
//------------------------------------------------------------------------------

const fileNameRegExp = /^config.jsx$/;

const variableNameRegExp = /^((pageIdentifier)|(pageName)|(reducerConfigList)|(pluginEnum)|(pluginConfig)|(getComponent)|(isStaticPage)|(getHelpDoc)|(isHideCloseIcon)|(beforePanelClose)|(alwaysNeedInitialization)|(disableBackupAndRestore)|(initReduxWithFrame)|(asyncPluginConfig)|(MODEL)|(VIEW)|(SUFFIX)|(isReloadIconHidden)|(staticPanelRefresh)|(enableFullScreen))$/;


const checkVariableName = (node, context) => {
    const nodeName = node.name;
    if (!variableNameRegExp.test(nodeName)) {

            context.report({
                node,
                messageId: 'invalidName'
            });

    }
};

module.exports = {
    meta: {
        docs: {
            description: "no custom variables exported in page config",
            category: "Fill me in",
            recommended: false
        },
        fixable: null,  // or "code" or "whitespace"
        schema: [
            // fill in your schema
        ],
        messages: {
            invalidName: `Do not define and export custom variables in page config.View all correct configurations at this address: https://10.80.5.116:9091/page/config.html`
        }
    },

    create: function (context) {

        // variables should be defined here

        //----------------------------------------------------------------------
        // Helpers
        //----------------------------------------------------------------------

        // any helper functions should go here or else delete this section

        //----------------------------------------------------------------------
        // Public
        //----------------------------------------------------------------------

        const fileNameArray = context.getFilename().split('\\');

        if (fileNameArray.indexOf('common') >= 0) {

            return {};

        }

        const fileName = fileNameArray.length ? fileNameArray[fileNameArray.length - 1] : '';

        if (!fileNameRegExp.test(fileName))  {

            return {};

        }

        return {

            // give me methods


            'ExportNamedDeclaration': (node) => {

                if (node.declaration.declarations) {

                    node.declaration.declarations.forEach(function (declaration) {

                        checkVariableName(declaration.id, context);

                    })
                }
                else {

                    /*if(node.declaration.type === 'FunctionDeclaration'){

                        console.log('node.declaration', node.declaration);

                        checkVariableName(node.declaration.id, context);

                    }*/
                }

            }


        };
    }
};
