/**
 * @fileoverview no pageIdentifier name which does not conform to naming conventions
 * @author acity
 */
"use strict";

//------------------------------------------------------------------------------
// Rule Definition
//------------------------------------------------------------------------------

const fileNameRegExp = /^config.jsx$/;

const getLegalName = fileNameArray => {

    let nameArray = [];

    let startIndex = fileNameArray.indexOf('components');

    if (startIndex < 0) {

        return false;

    }

    fileNameArray.forEach((item, index) => {

        if (index > startIndex && item !== 'config.jsx') {

            if (item.indexOf('_') >= 0) {

                let itemResult = item.split('_');

                nameArray = nameArray.concat(itemResult.map(word => word.substring(0, 1).toUpperCase() + word.substring(1)));

            }

            else {

                nameArray.push(item.substring(0, 1).toUpperCase() + item.substring(1));

            }
        }

    });

    let resultString = nameArray.join('');

    resultString = resultString.substring(0, 1).toLowerCase() + resultString.substring(1);

    return resultString;

};


const checkPageIdentifierName = (node, fileNameArray, context) => {

    if(!node.init.value && node.init.callee.name === 'getV5PageId'){

        return {};

    }

    const legalName = getLegalName(fileNameArray);

    if (legalName !== node.init.value) {

        context.report({
            node: node.id,
            messageId: 'illegalPageIdentifier'
        });

    }
};

module.exports = {
    meta: {
        docs: {
            description: "no pageIdentifier name which does not conform to naming conventions",
            category: "Fill me in",
            recommended: false
        },
        fixable: null,  // or "code" or "whitespace"
        schema: [
            // fill in your schema
        ],
        messages: {
            illegalPageIdentifier: `no illegal pageIdentifier name which does not conform to naming conventions.View the pageIdentifier-naming conventions at this address: https://10.80.5.116:9091/page/config.html#%E9%A1%B5%E9%9D%A2id`
        }
    },

    create: function (context) {

        // variables should be defined here

        //----------------------------------------------------------------------
        // Helpers
        //----------------------------------------------------------------------

        // any helper functions should go here or else delete this section

        //----------------------------------------------------------------------
        // Public
        //----------------------------------------------------------------------

        const fileNameArray = context.getFilename().split('\\');

        if (fileNameArray.indexOf('common') >= 0) {

            return {};

        }

        const fileName = fileNameArray.length ? fileNameArray[fileNameArray.length - 1] : '';

        if (!fileNameRegExp.test(fileName)) {
            return {};
        }

        return {

            // give me methods


            'ExportNamedDeclaration': (node) => {

                if (node.declaration.declarations) {

                    node.declaration.declarations.forEach(function (declaration) {

                        if (declaration.id.name === 'pageIdentifier') {

                            checkPageIdentifierName(declaration, fileNameArray, context);

                        }

                    })
                }

            }


        };
    }
};
