/**
 * @fileoverview no custom variables exported in page config
 * @author acity
 */
"use strict";

//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

var rule = require("../../../lib/rules/no-duplicate-i18n-word"),

    RuleTester = require("eslint").RuleTester;

const parserOptions = {
    "ecmaFeatures": {
        "jsx": true,
        "modules": true
    },
    "sourceType": "module",
    "ecmaVersion": 7
};


//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

var ruleTester = new RuleTester({parserOptions});
ruleTester.run("no-duplicate-i18n-word", rule, {

    valid: [
        {
            code: `
           
                export const dictionary = {
                    menu: {
                        zh: '菜单',
                        en: 'menu'
                    },
                    reportQueryOvertime: {
                        zh: '查询超时，请减少查询设备数量或缩短查询时间',
                        en: 'Query overtime，search less devices or time please'
                    },
                    scatterPointTitle1: {
                        zh: '散点图',
                        en: 'Scatter Chart'
                    },
                    boosterTips: {
                        zh: '正在加载...',
                        en: 'Loading...'
                    }
                }
   
            `,
            filename: "i18n\\index.js"
        }

        // give me some code that won't trigger a warning
    ],

    invalid: [
        {
            code: `
                export const dictionary = {
                    menu: {
                        zh: '菜单',
                        en: 'menu'
                    },
                    reportQueryOvertime: {
                        zh: '查询超时，请减少查询设备数量或缩短查询时间',
                        en: 'Query overtime，search less devices or time please'
                    },
                    boosterTips: {
                        zh: '正在加载...',
                        en: 'Loading...'
                    },
                    scatterPointTitle1: {
                        zh: '散点图',
                        en: 'Scatter Chart'
                    },
                    modelLoading: {
                        zh: "正在加载1...",
                        en: 'Loading'
                    },
                    modelLoading1: {
                        zh: "正在加载1...",
                        en: 'Loading2'
                    }
                }

            `,
            errors: [{
                messageId: "duplicateName"
            }],
            filename: "i18n\\index.js"
        }
    ]
});
