/**
 * @fileoverview no custom variables exported in page config
 * @author acity
 */
"use strict";

//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

var rule = require("../../../lib/rules/no-illegal-pageIdentifier"),

    RuleTester = require("eslint").RuleTester;

const parserOptions = {
    "ecmaFeatures": {
        "jsx": true,
        "modules": true
    },
    "sourceType": "module",
    "ecmaVersion": 7
};


//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

var ruleTester = new RuleTester({parserOptions});
ruleTester.run("no-illegal-pageIdentifier", rule, {

    valid: [
        {
            code: `
           

import React from "react";
import {Analysis, AsyncComponent} from "@common";
import {reducerConfigList as ReportQueryBarConfig} from "@common/report/query_bar/config.jsx";

export const pageName = "故障查询";

export const MODEL = 'accidentRecall';
export const VIEW = 'index';
export const pageIdentifier = getV5PageId(MODEL, VIEW);

export const reducerConfigList = [
    {
        name: 'isLoading',
        initialState: false
    }
];

export const pluginEnum = {
    ReportQueryBar: 'reportQueryBar'
};

export const pluginConfig = [
    {
        key: pluginEnum.ReportQueryBar,
        plugin: ReportQueryBarConfig
    }
];


   
            `,
            filename: "soamView\\components\\report\\fault_inquire\\config.jsx"
        }

        // give me some code that won't trigger a warning
    ],

    invalid: [
        {
            code: `
            export const pluginEnum = {
    Tree: "tree",
    TreeRole: "TreeRole",
    Pagination: "Pagination"
};

export const pageIdentifier = "warnSetting";

            `,
            errors: [{
                messageId: "illegalPageIdentifier"
            }],
            filename: "soamView\\components\\system\\warn_setting\\config.jsx"
        }
    ]
});
