/**
 * @fileoverview no custom variables exported in page config
 * @author acity
 */
"use strict";

//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

var rule = require("../../../lib/rules/no-miniui-class"),

    RuleTester = require("eslint").RuleTester;

const parserOptions = {
    "ecmaFeatures": {
        "jsx": true,
        "modules": true
    },
    "sourceType": "module",
    "ecmaVersion": 7
};


//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

var ruleTester = new RuleTester({parserOptions});
ruleTester.run("no-miniui-class", rule, {

    valid: [
        {
            code: `
           

import React from "react";
import {filter} from '@common';
import Icon from 'antd/lib/icon';
import Empty from 'antd/lib/empty';
import 'antd/lib/empty/style/css';
import styles from './styles.scss';

const Component = ({
                       //outer props
                       text,
                       hasCreateButton,
    onCreate

                       //outer actions

                       //redux props

                       //redux actions


                   }) => {

    return (

        <div>

            <Empty image={
                <Icon type="inbox" className={styles.icon}/>
            }
                   description={
                       text ? text : filter.format('%i18n', 'noData')
                   }>

                {
                    hasCreateButton ? <div className={styles.create} onClick={onCreate}>
                        <Icon type="plus-square" />立即创建
                    </div> : null
                }

            </Empty>

        </div>
    )
};

export default Component;

   
            `,
            filename: "soamView\\components\\report\\fault_inquire\\config.jsx"
        }

        // give me some code that won't trigger a warning
    ],

    invalid: [
        {
            code: `

import React from "react";
import {filter} from '@common';
import Icon from 'antd/lib/icon';
import Empty from 'antd/lib/empty';
import 'antd/lib/empty/style/css';
import styles from './styles.scss';

const Component = ({
                       //outer props
                       text,
                       hasCreateButton,
    onCreate

                       //outer actions

                       //redux props

                       //redux actions


                   }) => {

    return (

        <div className='mini-layout'>

            <Empty image={
                <Icon type="inbox" className={styles.icon}/>
            }
                   description={
                       text ? text : filter.format('%i18n', 'noData')
                   }>

                {
                    hasCreateButton ? <div className={'mini1-bbb'} onClick={onCreate}>
                        <Icon type="plus-square" />立即创建
                    </div> : null
                }

            </Empty>

        </div>
    )
};

export default Component;

            `,
            errors: [{
                messageId: "illegalClassName"
            }],
            filename: "soamView\\components\\system\\warn_setting\\config.jsx"
        }
    ]
});
